"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
/**
 * Retrieves the display name from a given ref name.
 * @param {string} refName - The ref name
 * @returns {string} The display name, or null if the ref name does not contain a display name.
 */
var getDisplayName = exports.getDisplayName = function getDisplayName(refName) {
  if (!refName || refName.charAt(refName.length - 1) !== "'") {
    return null;
  }

  var start = refName.indexOf("'");

  if (start < 0 || start === refName.length - 1) {
    return null;
  }

  return refName.substring(start + 1, refName.length - 1);
};

/**
 * Retrieves the service path from a given ref name.
 * @param {string} refName - The ref name
 * @returns {string} The service path, or null if the ref name does not contain a service path.
 */
var getServicePath = exports.getServicePath = function getServicePath(refName) {
  if (!refName) {
    return null;
  }

  var parts = refName.split(':', 4);

  return parts[3] || null;
};

/**
 * Retrieves the vocabulary shord identifier from a given ref name.
 * @param {string} refName - The ref name
 * @returns {string} The short ID, or null if the ref name does not contain a vocabulary short ID.
 */
var getVocabularyShortID = exports.getVocabularyShortID = function getVocabularyShortID(refName) {
  if (!refName) {
    return null;
  }

  var parts = refName.split(':', 6);
  var itemPart = parts[5];

  if (itemPart === 'item') {
    var vocabNamePart = parts[4];

    if (vocabNamePart && vocabNamePart.indexOf('name(') === 0 && vocabNamePart.lastIndexOf(')') === vocabNamePart.length - 1) {
      return vocabNamePart.substring(5, vocabNamePart.length - 1);
    }
  }

  return null;
};

/**
 * Retrieves the vocabulary item short identifier from a given ref name.
 * @param {string} refName - The ref name
 * @returns {string} The short ID, or null if the ref name does not contain a vocabulary item
 * short ID.
 */
var getItemShortID = exports.getItemShortID = function getItemShortID(refName) {
  if (!refName) {
    return null;
  }

  var parts = refName.split(':', 7);
  var itemPart = parts[5];

  if (itemPart === 'item') {
    var itemNamePart = parts[6];

    if (itemNamePart && itemNamePart.indexOf('name(') === 0) {
      var index = itemNamePart.indexOf(')');

      if (index > -1) {
        return itemNamePart.substring(5, index);
      }
    }
  }

  return null;
};